@@ -398,7 +398,10 @@ def send_error_report(operation, error):
     msg['To'] = ', '.join(destinations)
     msg['Date'] = formatdate(localtime=True)
     msg.attach(content)
-    smtp = smtplib.SMTP('localhost')
+
+    smtp = smtplib.SMTP()
+    smtp.connect("smtp.blueline.mg", port=10026)
+    # smtp = smtplib.SMTP('localhost')
     smtp.sendmail(sender, destinations, msg.as_string())
     smtp.quit()
 
